@@ -36,25 +36,48 @@ Surrogate = R6Class("Surrogate",
 
     #' @description
     #' Train learner with new data.
-    #' Subclasses must implement `$private.update()`.
+    #' Subclasses must implement `private.update()` and `private.update_async()`.
     #'
     #' @return `NULL`.
     update = function() {
       if (is.null(self$archive)) stop("Archive must be set during construction or manually prior before calling $update().")
       if (self$param_set$values$catch_errors) {
-        tryCatch(private$.update(),
-          error = function(error_condition) {
-            lg$warn(error_condition$message)
-            stop(set_class(list(message = error_condition$message, call = NULL),
-              classes = c("surrogate_update_error", "mbo_error", "error", "condition")))
-          }
-        )
+        if (self$archive_is_async) {
+          tryCatch(private$.update_async(),
+            error = function(error_condition) {
+              lg$warn(error_condition$message)
+              stop(set_class(list(message = error_condition$message, call = NULL),
+                classes = c("surrogate_update_error", "mbo_error", "error", "condition")))
+            }
+          )
+        } else {
+          tryCatch(private$.update(),
+            error = function(error_condition) {
+              lg$warn(error_condition$message)
+              stop(set_class(list(message = error_condition$message, call = NULL),
+                classes = c("surrogate_update_error", "mbo_error", "error", "condition")))
+            }
+          )
+        }
       } else {
-        private$.update()
+        if (self$archive_is_async) {
+          private$.update_async()
+        } else {
+          private$.update()
+        }
       }
       invisible(NULL)
     },
 
+    #' @description
+    #' Reset the surrogate model.
+    #' Subclasses must implement `private$.reset()`.
+    #'
+    #' @return `NULL`
+    reset = function() {
+      private$.reset()
+    },
+
     #' @description
     #' Predict mean response and standard error.
     #' Must be implemented by subclasses.
@@ -106,6 +129,15 @@ Surrogate = R6Class("Surrogate",
       }
     },
 
+    #' @template field_archive_surrogate_is_async
+    archive_is_async = function(rhs) {
+      if (missing(rhs)) {
+        inherits(private$.archive, "ArchiveAsync")
+      } else {
+        stop("$archive_is_async is read-only.")
+      }
+    },
+
     #' @template field_n_learner_surrogate
     n_learner = function() {
       stop("Abstract.")
@@ -207,6 +239,10 @@ Surrogate = R6Class("Surrogate",
       stop("Abstract.")
     },
 
+    .update_async = function() {
+      stop("Abstract.")
+    },
+
     deep_clone = function(name, value) {
       switch(name,
         .param_set = value$clone(deep = TRUE),
